/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.1
 *  Last Modified: 30 May 2011
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef REGISTRO_LLAMADAS_H
#define REGISTRO_LLAMADAS_H

#include <QDialog>
#include <QtNetwork/QtNetwork>
#include <QUrl>

#include "main.h"
#include "llamada_saliente.h"
#include "entrada.h"

QT_BEGIN_NAMESPACE

class QAbstractItemModel;

QT_END_NAMESPACE

namespace Ui {
    class Registro_llamadas;
}

class Registro_llamadas : public QDialog
{
    Q_OBJECT

private slots:

    /**
    @brief Slot que se ejecutara cuando clickeamos dos veces sobre un contacto

    Realiza una llamada al numero asociado al contacto que tengamos seleccionado.
    */
    void llamar();

    /**
    @brief Slot que se ejecutara cuando seleccionemos la opcion de 'aadir'

    Crea una nueva entrada con los parametro que le introduzcamos en el dialogo 'entrada'.
    */
    void nuevaEntrada();


public:

    /**
    @brief Constructor por defecto
    @param dirpath Contiene el path donde se encuentra el fichero de audio a reproducir
    @param parent widget Padre
    */
    explicit Registro_llamadas(Entrada * t, QString dirpath = "./",QWidget *parent = 0);

    /**
    @brief Aade una nueva entrada a la tabla de llamadas
    @param nombre Contiene el nombre de la llamada entrante
    @param telefono Contiene el telefono de la llamada entrante
    @param imp Especifica si la llamada entrante es importante o no
    @param entr Especifica si la llamada es entrante o no
    */
    void addEntrada(const QString &nombre,const QString &telefono, const bool &imp = false, const bool &entr = true);

    /**
    @brief Destructor por defecto

    Libera la memoria reservada
    */
    ~Registro_llamadas();


private:

    /**
    @brief Crea un conjunto de acciones asociandolas a los slots anteriores

    Define un conjunto de acciones, asignandoles iconos, teclas de acceso rapido, informacion, etc....
    */
    void crearAcciones();

    /**
    @brief Crea el menu que se muestra cuando clickeamos con el boton derecho sobre un contacto

    Crea el menu que se muestra cuando clickeamos con el boton derecho sobre un contacto asignandole las
    acciones mas usuales que podriamos necesitar (editar, borrar, llamar, etc...).
    */
    void crearMenusContextuales();

    Ui::Registro_llamadas *ui;
    QAbstractItemModel *modelo; // Modelo tabla central
    QUrl url; // Url para llamar
    QNetworkAccessManager qnam;
    Llamada_saliente * llam_sal; // Muestra la informacion al llamar
    QString path; // Donde esta la aplicacion
    Entrada * ent;
    QAction *addAction; // aadir
    int n_ent; // numero de llamadas entrantes
    int n_sal; // salientes
    int n_imp; // Importantes

    /**
    @brief Devuelve el numero de la fila seleccionada en la tabla
    @return numero de fila seleccionada
    */
    int filaSeleccionada();
};

#endif // Registro_llamadas_H
